@@ -22,10 +22,14 @@
  * Boston, MA 02111-1307, USA.  
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gdl-i18n.h"
 #include <string.h>
 #include <gtk/gtkhpaned.h>
 #include <gtk/gtkvpaned.h>
-#include <libgnome/gnome-macros.h>
 
 #include "gdl-tools.h"
 #include "gdl-dock-paned.h"
@@ -86,7 +90,7 @@ enum {
 
 /* ----- Private functions ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDockPaned, gdl_dock_paned, GdlDockItem, GDL_TYPE_DOCK_ITEM);
+GDL_CLASS_BOILERPLATE (GdlDockPaned, gdl_dock_paned, GdlDockItem, GDL_TYPE_DOCK_ITEM);
 
 static void
 gdl_dock_paned_class_init (GdlDockPanedClass *klass)
@@ -173,7 +177,7 @@ gdl_dock_paned_button_cb (GtkWidget      *widget,
         else {
             GDL_DOCK_ITEM_UNSET_FLAGS (user_data, GDL_DOCK_USER_ACTION);
             if (paned->position_changed) {
-                /* emit pending layout changed signal */
+                /* emit pending layout changed signal to track separator position */
                 if (GDL_DOCK_OBJECT (paned)->master)
                     g_signal_emit_by_name (GDL_DOCK_OBJECT (paned)->master, "layout_changed");
                 paned->position_changed = FALSE;
@@ -220,7 +224,7 @@ gdl_dock_paned_constructor (GType                  type,
 {
     GObject *g_object;
     
-    g_object = GNOME_CALL_PARENT_WITH_DEFAULT (G_OBJECT_CLASS, 
+    g_object = GDL_CALL_PARENT_WITH_DEFAULT (G_OBJECT_CLASS, 
                                                constructor, 
                                                (type,
                                                 n_construct_properties,
@@ -288,7 +292,7 @@ gdl_dock_paned_destroy (GtkObject *object)
 
     /* we need to call the virtual first, since in GdlDockDestroy our
        children dock objects are detached */
-    GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+    GDL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 
     /* after that we can remove the GtkNotebook */
     if (item->child) {
@@ -341,7 +345,7 @@ gdl_dock_paned_forall (GtkContainer *container,
 
     if (include_internals) {
         /* use GdlDockItem's forall */
-        GNOME_CALL_PARENT (GTK_CONTAINER_CLASS, forall, 
+        GDL_CALL_PARENT (GTK_CONTAINER_CLASS, forall, 
                            (container, include_internals, callback, callback_data));
     }
     else {
@@ -564,7 +568,7 @@ gdl_dock_paned_dock (GdlDockObject    *object,
 
     if (!done) {
         /* this will create another paned and reparent us there */
-        GNOME_CALL_PARENT (GDL_DOCK_OBJECT_CLASS, dock, (object, requestor, position,
+        GDL_CALL_PARENT (GDL_DOCK_OBJECT_CLASS, dock, (object, requestor, position,
                                                          other_data));
     }
     else {
@@ -610,7 +614,7 @@ gdl_dock_paned_set_orientation (GdlDockItem    *item,
         }
     }
     
-    GNOME_CALL_PARENT (GDL_DOCK_ITEM_CLASS, set_orientation, (item, orientation));
+    GDL_CALL_PARENT (GDL_DOCK_ITEM_CLASS, set_orientation, (item, orientation));
 }
 
 static gboolean 
