@@ -2,7 +2,7 @@
  *
  * This file is part of the GNOME Devtools Libraries.
  *
- * Copyright (C) 2002 Gustavo Girldez <gustavo.giraldez@gmx.net>
+ * Copyright (C) 2002 Gustavo Giráldez <gustavo.giraldez@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,14 @@
  * Boston, MA 02111-1307, USA.  
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gdl-i18n.h"
 #include <stdlib.h>
 #include <string.h>
 #include <gdk/gdkx.h>
-#include <libgnome/gnome-macros.h>
 
 #include "gdl-tools.h"
 #include "gdl-dock.h"
@@ -117,7 +121,7 @@ struct _GdlDockPrivate
     gint                float_y;
     gint                width;
     gint                height;
-    
+
     /* auxiliary fields */
     GdkGC              *xor_gc;
 };
@@ -144,7 +148,7 @@ static guint dock_signals [LAST_SIGNAL] = { 0 };
 
 /* ----- Private functions ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDock, gdl_dock, GdlDockObject, GDL_TYPE_DOCK_OBJECT);
+GDL_CLASS_BOILERPLATE (GdlDock, gdl_dock, GdlDockObject, GDL_TYPE_DOCK_OBJECT);
 
 static void
 gdl_dock_class_init (GdlDockClass *klass)
@@ -290,7 +294,7 @@ gdl_dock_constructor (GType                  type,
 {
     GObject *g_object;
     
-    g_object = GNOME_CALL_PARENT_WITH_DEFAULT (G_OBJECT_CLASS, 
+    g_object = GDL_CALL_PARENT_WITH_DEFAULT (G_OBJECT_CLASS, 
                                                constructor, 
                                                (type,
                                                 n_construct_properties,
@@ -435,7 +439,11 @@ gdl_dock_get_property  (GObject      *object,
                 g_object_get (GDL_DOCK_OBJECT (object)->master,
                               "default_title", &default_title,
                               NULL);
+#if GLIB_CHECK_VERSION(2,3,0)
+                g_value_take_string (value, default_title);
+#else
                 g_value_set_string_take_ownership (value, default_title);
+#endif
             }
             else
                 g_value_set_string (value, NULL);
@@ -532,16 +540,16 @@ gdl_dock_destroy (GtkObject *object)
         g_free (priv);
     }
     
-    GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+    GDL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
 gdl_dock_size_request (GtkWidget      *widget,
                        GtkRequisition *requisition)
 {
-    GdlDock      *dock;
-    GtkContainer *container;
-    guint         border_width;
+    GdlDock       *dock;
+    GtkContainer  *container;
+    guint          border_width;
 
     g_return_if_fail (widget != NULL);
     g_return_if_fail (GDL_IS_DOCK (widget));
@@ -568,9 +576,9 @@ static void
 gdl_dock_size_allocate (GtkWidget     *widget,
                         GtkAllocation *allocation)
 {
-    GdlDock      *dock;
-    GtkContainer *container;
-    guint         border_width;
+    GdlDock       *dock;
+    GtkContainer  *container;
+    guint          border_width;
 
     g_return_if_fail (widget != NULL);
     g_return_if_fail (GDL_IS_DOCK (widget));
@@ -602,7 +610,7 @@ gdl_dock_map (GtkWidget *widget)
 
     dock = GDL_DOCK (widget);
 
-    GNOME_CALL_PARENT (GTK_WIDGET_CLASS, map, (widget));
+    GDL_CALL_PARENT (GTK_WIDGET_CLASS, map, (widget));
 
     if (dock->root) {
         child = GTK_WIDGET (dock->root);
@@ -622,7 +630,7 @@ gdl_dock_unmap (GtkWidget *widget)
 
     dock = GDL_DOCK (widget);
 
-    GNOME_CALL_PARENT (GTK_WIDGET_CLASS, unmap, (widget));
+    GDL_CALL_PARENT (GTK_WIDGET_CLASS, unmap, (widget));
 
     if (dock->root) {
         child = GTK_WIDGET (dock->root);
@@ -652,7 +660,7 @@ gdl_dock_show (GtkWidget *widget)
     g_return_if_fail (widget != NULL);
     g_return_if_fail (GDL_IS_DOCK (widget));
     
-    GNOME_CALL_PARENT (GTK_WIDGET_CLASS, show, (widget));
+    GDL_CALL_PARENT (GTK_WIDGET_CLASS, show, (widget));
     
     dock = GDL_DOCK (widget);
     if (dock->_priv->floating && dock->_priv->window)
@@ -673,7 +681,7 @@ gdl_dock_hide (GtkWidget *widget)
     g_return_if_fail (widget != NULL);
     g_return_if_fail (GDL_IS_DOCK (widget));
     
-    GNOME_CALL_PARENT (GTK_WIDGET_CLASS, hide, (widget));
+    GDL_CALL_PARENT (GTK_WIDGET_CLASS, hide, (widget));
     
     dock = GDL_DOCK (widget);
     if (dock->_priv->floating && dock->_priv->window)
@@ -944,10 +952,8 @@ gdl_dock_floating_window_delete_event_cb (GtkWidget *widget)
     
     dock = GDL_DOCK (g_object_get_data (G_OBJECT (widget), "dock"));
     if (dock->root) {
-        GdlDockMaster *master = GDL_DOCK_OBJECT_GET_MASTER (dock);
         /* this will call reduce on ourselves, hiding the window if appropiate */
         gdl_dock_item_hide_item (GDL_DOCK_ITEM (dock->root));
-        g_signal_emit_by_name (master, "layout_changed");
     }
 
     return TRUE;
@@ -1200,4 +1206,3 @@ gdl_dock_xor_rect (GdlDock      *dock,
                         rect->x + 1, rect->y + 1,
                         rect->width - 2, rect->height - 2);
 }
-
